==> MoarSigns-1.10.2-4.2.1.7-sources.jar: gory_moon/moarsigns/client/interfaces/GuiExchange.java <==
package gory_moon.moarsigns.client.interfaces;

import gory_moon.moarsigns.client.interfaces.containers.ContainerExchange;
import gory_moon.moarsigns.client.interfaces.containers.InventoryExchange;
import gory_moon.moarsigns.items.ItemSignToolbox;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.inventory.GuiContainer;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.InventoryPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.opengl.GL11;

import java.util.Iterator;

public class GuiExchange extends GuiContainer {

    private static final ResourceLocation texture = new ResourceLocation("moarsigns", "textures/gui/sign_exchange.png");

    public EntityPlayer player;

    public GuiExchange(InventoryPlayer inventory, InventoryExchange exchangeInv) {
        super(new ContainerExchange(inventory, exchangeInv));

        player = inventory.field_70458_d;
        field_146999_f = 226;
        field_147000_g = 162;
    }

    @Override
    public void func_146281_b() {
        super.func_146281_b();
        field_147002_h.func_75134_a(player);
    }

    @Override
    public void func_73876_c() {
        super.func_73876_c();

        Iterator<ItemStack> held = player.func_184214_aD().iterator();
        boolean isHolding = false;
        while (held.hasNext()) {
            ItemStack tmp = held.next();
            if (tmp != null && (tmp.func_77973_b() instanceof ItemSignToolbox)) {
                isHolding = true;
            }
        }

        if (!isHolding) {
            field_146297_k.func_147108_a(null);
        }
    }

    @Override
    protected void func_146976_a(float p_146976_1_, int p_146976_2_, int p_146976_3_) {
        GL11.glColor4f(1, 1, 1, 1);

        Minecraft.func_71410_x().func_110434_K().func_110577_a(texture);
        func_73729_b(field_147003_i, field_147009_r, 0, 0, field_146999_f, field_147000_g);
    }
}

==> MoarSigns-1.12.2-6.0.0.11-sources.jar: gory_moon/moarsigns/client/interfaces/GuiExchange.java <==
package gory_moon.moarsigns.client.interfaces;

import gory_moon.moarsigns.client.interfaces.containers.ContainerExchange;
import gory_moon.moarsigns.client.interfaces.containers.InventoryExchange;
import gory_moon.moarsigns.items.ItemSignToolbox;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.inventory.GuiContainer;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.InventoryPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumHand;
import net.minecraft.util.ResourceLocation;
import org.lwjgl.opengl.GL11;

import java.util.Iterator;

public class GuiExchange extends GuiContainer {

    private static final ResourceLocation texture = new ResourceLocation("moarsigns", "textures/gui/sign_exchange.png");

    public EntityPlayer player;

    public GuiExchange(InventoryPlayer inventory, InventoryExchange exchangeInv, EnumHand hand) {
        super(new ContainerExchange(inventory, exchangeInv, hand));

        player = inventory.field_70458_d;
        field_146999_f = 226;
        field_147000_g = 162;
    }

    @Override
    public void func_146281_b() {
        super.func_146281_b();
        field_147002_h.func_75134_a(player);
    }

    @Override
    public void func_73863_a(int mouseX, int mouseY, float partialTicks) {
        this.func_146276_q_();
        super.func_73863_a(mouseX, mouseY, partialTicks);
        this.func_191948_b(mouseX, mouseY);
    }

    @Override
    public void func_73876_c() {
        super.func_73876_c();

        Iterator<ItemStack> held = player.func_184214_aD().iterator();
        boolean isHolding = false;
        while (held.hasNext()) {
            ItemStack tmp = held.next();
            if (tmp != null && (tmp.func_77973_b() instanceof ItemSignToolbox)) {
                isHolding = true;
            }
        }

        if (!isHolding) {
            field_146297_k.func_147108_a(null);
        }
    }

    @Override
    protected void func_146976_a(float p_146976_1_, int p_146976_2_, int p_146976_3_) {
        GL11.glColor4f(1, 1, 1, 1);

        Minecraft.func_71410_x().func_110434_K().func_110577_a(texture);
        func_73729_b(field_147003_i, field_147009_r, 0, 0, field_146999_f, field_147000_g);
    }
}
